@@ -1,16 +1,18 @@
-//use ruma_identifiers::{RoomId, UserId};
+//use ruma_identifiers::{Box<RoomId>, Box<UserId>};
 //use serde::{Serialize, Deserialize};
-use crackle_lib::{RoomAliasId, RoomId, RoomName, UserId};
+use crackle_lib::{RoomAliasId, RoomId, RoomName, ServerName, UserId};
 use crossbeam_channel::{unbounded, TryRecvError};
 use crossterm::{
     event::{self, DisableMouseCapture, EnableMouseCapture, Event, KeyCode},
     execute,
-    terminal::{disable_raw_mode, enable_raw_mode, EnterAlternateScreen, LeaveAlternateScreen},
+    terminal::{
+        disable_raw_mode, enable_raw_mode, EnterAlternateScreen, LeaveAlternateScreen, SetTitle,
+    },
 };
 use scanpw::scanpw;
 use serde::{Deserialize, Serialize};
 use std::collections::BTreeMap;
-use std::convert::TryFrom;
+//use std::convert::TryFrom;
 //use ruma_client_api::sync;
 use std::{error::Error, io};
 use tui::{
@@ -75,21 +77,21 @@ struct App {
     /// Current input mode
     focus: Focus,
     /// History of recorded messages
-    messages: BTreeMap<RoomId, Vec<String>>,
+    messages: BTreeMap<Box<RoomId>, Vec<String>>,
     host: String,
     server_name: String,
     user_name: String,
     password: Option<String>,
-    selected_room: Option<RoomId>,
+    selected_room: Option<Box<RoomId>>,
     room: String,
-    rooms: BTreeMap<RoomId, Box<RoomName>>,
-    current_room: Option<RoomId>,
-    room_id_to_canonical_alias: BTreeMap<RoomId, RoomAliasId>,
+    rooms: BTreeMap<Box<RoomId>, Box<RoomName>>,
+    current_room: Option<Box<RoomId>>,
+    room_id_to_canonical_alias: BTreeMap<Box<RoomId>, Box<RoomAliasId>>,
     auth_token: Option<String>,
-    joined_rooms: Vec<RoomId>,
-    room_to_direct_name: BTreeMap<RoomId, String>,
-    room_to_aliases: BTreeMap<RoomId, Vec<RoomAliasId>>,
-    alias_to_room: BTreeMap<RoomAliasId, RoomId>,
+    joined_rooms: Vec<Box<RoomId>>,
+    room_to_direct_name: BTreeMap<Box<RoomId>, String>,
+    room_to_aliases: BTreeMap<Box<RoomId>, Vec<Box<RoomAliasId>>>,
+    alias_to_room: BTreeMap<Box<RoomAliasId>, Box<RoomId>>,
     room_list_top: usize,
     room_list_height: usize,
     room_list_top_backup: usize,
@@ -117,7 +119,17 @@ impl App {
             .map(|z| z.to_string())
             .collect::<Vec<String>>()[0]
             .clone();
-        let username = match UserId::try_from(user_name.clone()) {
+        let mut good_username = user_name.clone();
+        if good_username.starts_with("@") {
+            good_username = good_username.split_once("@").unwrap().1.to_string();
+            if good_username.contains(":") {
+                good_username = good_username.split_once(":").unwrap().0.to_string();
+            }
+        }
+        let username = match UserId::parse_with_server_name(
+            good_username,
+            &ServerName::parse(server_name.as_str()).unwrap(),
+        ) {
             Ok(user_id) => user_id.localpart().to_string(),
             Err(_) => user_name.clone(),
         };
@@ -179,7 +191,12 @@ async fn main() -> Result<(), Box<dyn Error>> {
     // setup terminal
     enable_raw_mode()?;
     let mut stdout = io::stdout();
-    execute!(stdout, EnterAlternateScreen, EnableMouseCapture)?;
+    execute!(
+        stdout,
+        EnterAlternateScreen,
+        EnableMouseCapture,
+        SetTitle("Crackle")
+    )?;
     let backend = CrosstermBackend::new(stdout);
     let mut terminal = Terminal::new(backend)?;
 
@@ -204,93 +221,82 @@ async fn main() -> Result<(), Box<dyn Error>> {
     terminal.show_cursor()?;
 
     if let Err(err) = res {
-        println!("{:?}", err)
+        println!("{:?}", err);
     }
 
     Ok(())
 }
-/*
-async fn sync(client: ruma_client::Client::<ruma_client::http_client::Reqwest>, since: Option<String>, full_state: bool) -> sync::sync_events::v3::Response {
-    let mut sync_request = sync::sync_events::v3::Request::new();
-    sync_request.full_state = full_state;
-    sync_request.timeout = Some(TIMEOUT);
-    let mut sync_result = client.send_request(sync_request.clone()).await;
-    while sync_result.is_err() {
-        sync_result = client.send_request(sync_request.clone()).await;
-    }
-    //let sync_response: sync::sync_events::v3::Response = s
-    sync_result.unwrap()
-}
-*/
 #[derive(Debug, Clone, Eq, PartialEq)]
 enum SyncMessage {
     Quit,
-    //Response(sync::sync_events::v3::Response),
-    SendMessage(RoomId, String, String),
+    SendMessage(Box<RoomId>, String, String, bool),
     InitialSyncOver,
     RoomsUpdated(
-        Vec<RoomId>,
-        BTreeMap<RoomId, Box<RoomName>>,
-        BTreeMap<RoomId, RoomAliasId>,
-        BTreeMap<RoomId, String>,
-        BTreeMap<RoomId, Vec<RoomAliasId>>,
-        BTreeMap<RoomAliasId, RoomId>,
+        Vec<Box<RoomId>>,
+        BTreeMap<Box<RoomId>, Box<RoomName>>,
+        BTreeMap<Box<RoomId>, Box<RoomAliasId>>,
+        BTreeMap<Box<RoomId>, String>,
+        BTreeMap<Box<RoomId>, Vec<Box<RoomAliasId>>>,
+        BTreeMap<Box<RoomAliasId>, Box<RoomId>>,
     ),
-    LeaveRoom(RoomId),
+    LeaveRoom(Box<RoomId>),
     JoinRoom(String),
 }
 #[allow(unused_assignments)]
-async fn run_app<B: Backend>(terminal: &mut Terminal<B>, mut app: App) -> io::Result<()> {
+async fn run_app<B: Backend>(terminal: &mut Terminal<B>, mut app: App) -> Result<(), String> {
+    let authentication: crackle_lib::Authentication;
+    if let Some(pass) = app.password.clone() {
+        /*
+        if let Err(val) = client.login(pass) {
+            return Err(format!("Error logging in: {:#?}", val));
+        }
+        */
+        authentication = crackle_lib::Authentication::Password(pass);
+    } else {
+        //client.set_auth_token(app.auth_token.as_ref().unwrap().clone());
+        authentication = crackle_lib::Authentication::AuthToken(app.auth_token.clone().unwrap());
+    }
     let mut client = crackle_lib::Client::new(
         app.host.clone(),
         app.user_name.clone(),
         app.server_name.clone(),
-    );
-    if let Some(pass) = app.password.clone() {
-        client.login(pass);
-    } else {
-        client.set_auth_token(app.auth_token.as_ref().unwrap().clone());
-    }
+        authentication,
+    )
+    .await;
     let me = client.get_me();
     let (tx1, rx1) = unbounded::<SyncMessage>();
     let tx1_clone = tx1.clone();
     let (tx2, rx2) = unbounded::<SyncMessage>();
-    //let rx_clone = rx.clone();
-    let sm_room_id = client.room_id_from_alias(app.room.clone());
+    let sm_room_id = client.room_id_from_alias(app.room.clone()).await;
     let sm_room_id_clone = sm_room_id.clone();
-    //let tx_clone = tx.clone();
     let networking = tokio::task::spawn(async move {
-        let mut sync_results = client.sync().unwrap();
-        //let mut known_room_list: Vec<RoomId> = Vec::new();
-        client.extract_data(sync_results.clone());
+        let mut sync_results = client.sync().await.unwrap();
+        client.extract_data(sync_results);
         tx1.send(SyncMessage::InitialSyncOver).unwrap();
         //let mut f = std::fs::File::create("sync.log").unwrap();
         //writeln!(f, "{:#?}", sync_results);
-        //client.join_with_alias(app.room);
-        //let mut sync_results = sync(client.clone(), None, true).await;
-        //let mut since = sync_results.next_batch;
-        //client.send_request(ruma_client_api::membership::join_room_by_id::v3::Request::new(&distrotube_room_id)).await.unwrap();
-        client.join_room_id(sm_room_id_clone);
+        client.join_room_id(sm_room_id_clone).await;
         loop {
             match rx2.try_recv() {
                 Ok(SyncMessage::Quit) => break,
-                Ok(SyncMessage::SendMessage(room_id, _user_id, message)) => {
-                    client.send_message(room_id.try_into().unwrap(), message);
+                Ok(SyncMessage::SendMessage(room_id, _user_id, message, _is_emote)) => {
+                    client
+                        .send_message(room_id.try_into().unwrap(), message)
+                        .await;
                 }
                 Ok(SyncMessage::LeaveRoom(room_id)) => {
-                    client.leave_room_id(room_id);
+                    client.leave_room_id(room_id).await;
                 }
                 Ok(SyncMessage::JoinRoom(room)) => {
-                    client.join_with_alias(room);
+                    client.join_with_alias(room).await;
                 }
                 Ok(_) => {}
                 Err(TryRecvError::Empty) => {}
                 Err(_) => break,
             }
-            sync_results = client.sync().unwrap();
+            sync_results = client.sync().await.unwrap();
             let messages = client.extract_data(sync_results.clone()); //, client.clone().me);
             if client.room_list_updated() {
-                //println!("{:#?}", client.data.joined_rooms);
                 tx1.send(SyncMessage::RoomsUpdated(
                     client.data.joined_rooms.clone(),
                     client.data.room_to_name.clone(),
@@ -305,156 +311,125 @@ async fn run_app<B: Backend>(terminal: &mut Terminal<B>, mut app: App) -> io::Re
                 let room_id = message.room_id;
                 let user_id = message.sender.to_string();
                 let msg = message.message.to_string();
-                //if room_id.clone() == distrotube_room_id {
-                tx1.send(SyncMessage::SendMessage(room_id, user_id, msg))
+                let is_emote = message.is_emote;
+                tx1.send(SyncMessage::SendMessage(room_id, user_id, msg, is_emote))
                     .unwrap();
-                //}
             }
         }
     });
     loop {
-        terminal.draw(|f| ui(f, &mut app))?;
+        terminal
+            .draw(|f| ui(f, &mut app))
+            .expect("Error drawing in terminal");
         if event::poll(std::time::Duration::from_secs(0)).unwrap() {
-            if let Event::Key(key) = event::read()? {
+            if let Event::Key(key) = event::read().expect("Error reading event") {
                 match app.focus {
-                    Focus::RoomSelect => {
-                        //let num_rooms = app.rooms.len();
-                        /*
-                        let mut prev: RoomId;
-                        let mut next: RoomId;
-                        let last = app.rooms.iter().last().unwrap().0;
-                        let first: RoomId;
-                        for (index_num, (room_id, _room_name)) in app.rooms.iter().enumerate() {
-                            if index_num == 0 {
-                                first = room_id;
-                            }
-                        }
-                        */
-                        match key.code {
-                            KeyCode::Up => {
-                                if app.joined_rooms.len() > 1 {
-                                    let last = app.joined_rooms.iter().last().unwrap();
-                                    let first = app.joined_rooms.iter().nth(0).unwrap();
-                                    let mut prev = last.clone();
-                                    for (index_num, room_id) in app.joined_rooms.iter().enumerate()
-                                    {
-                                        if index_num == 0 {
-                                            if first.clone() == app.selected_room.clone().unwrap() {
-                                                app.selected_room = Some(last.clone());
-                                                app.room_list_top = find_top(
-                                                    app.joined_rooms.len() - 1,
-                                                    app.room_list_height,
-                                                    app.joined_rooms.len(),
-                                                );
-                                                break;
-                                            }
-                                            prev = room_id.clone();
-                                        } else {
-                                            if room_id.clone() == app.selected_room.clone().unwrap()
-                                            {
-                                                if room_id.clone()
-                                                    == app.joined_rooms[app.room_list_top]
-                                                {
-                                                    app.room_list_top -= 1;
-                                                }
-                                                app.selected_room = Some(prev);
-                                                break;
-                                            }
-                                            prev = room_id.clone();
-                                        } //else {
-                                          //    app.selected_room = Some(last.clone());
-                                          //}
-                                    }
-                                }
-                            }
-                            KeyCode::Down => {
-                                if app.joined_rooms.len() > 1 {
-                                    let last = app.joined_rooms.iter().last().unwrap();
-                                    let first = app.joined_rooms.iter().nth(0).unwrap();
-                                    let mut use_next = false;
-                                    for room_id in app.joined_rooms.iter() {
-                                        if use_next {
-                                            if app.selected_room.clone().unwrap()
-                                                == app.joined_rooms[find_bottom(
-                                                    app.room_list_top,
-                                                    app.room_list_height,
-                                                    app.joined_rooms.len(),
-                                                )]
-                                            {
-                                                app.room_list_top += 1;
-                                            }
-                                            app.selected_room = Some(room_id.clone());
+                    Focus::RoomSelect => match key.code {
+                        KeyCode::Up => {
+                            if app.joined_rooms.len() > 1 {
+                                let last = app.joined_rooms.iter().last().unwrap();
+                                let first = app.joined_rooms.iter().nth(0).unwrap();
+                                let mut prev = last.clone();
+                                for (index_num, room_id) in app.joined_rooms.iter().enumerate() {
+                                    if index_num == 0 {
+                                        if first.clone() == app.selected_room.clone().unwrap() {
+                                            app.selected_room = Some(last.clone());
+                                            app.room_list_top = find_top(
+                                                app.joined_rooms.len() - 1,
+                                                app.room_list_height,
+                                                app.joined_rooms.len(),
+                                            );
                                             break;
-                                        } else if room_id != last {
-                                            if room_id.clone() == app.selected_room.clone().unwrap()
-                                            {
-                                                use_next = true;
-                                            }
-                                        } else {
-                                            app.selected_room = Some(first.clone());
-                                            app.room_list_top = 0;
                                         }
+                                        prev = room_id.clone();
+                                    } else {
+                                        if room_id.clone() == app.selected_room.clone().unwrap() {
+                                            if room_id.clone()
+                                                == app.joined_rooms[app.room_list_top]
+                                            {
+                                                app.room_list_top -= 1;
+                                            }
+                                            app.selected_room = Some(prev);
+                                            break;
+                                        }
+                                        prev = room_id.clone();
                                     }
                                 }
                             }
-                            KeyCode::Char('l') => {
-                                tx2.send(SyncMessage::LeaveRoom(
-                                    app.selected_room.clone().unwrap(),
-                                ))
-                                .unwrap();
-                                //app.rooms.remove(app.selected_room.as_ref().unwrap());
-                                app.selected_room = None;
-                                //app.current_room = None;
-                            }
-                            KeyCode::Char('j') => {
-                                app.focus = Focus::JoinRoomInput;
-                            }
-                            KeyCode::Enter => {
-                                app.current_room = Some(app.selected_room.clone().unwrap());
-                                app.selected_room = None;
-                                app.focus = Focus::Watching;
-                                app.room_list_top_backup = app.room_list_top;
-                            }
-                            KeyCode::Esc => {
-                                app.selected_room = None;
-                                app.focus = Focus::Watching;
-                                app.room_list_top = app.room_list_top_backup;
-                            }
-                            _ => {}
                         }
-                    }
+                        KeyCode::Down => {
+                            if app.joined_rooms.len() > 1 {
+                                let last = app.joined_rooms.iter().last().unwrap();
+                                let first = app.joined_rooms.iter().nth(0).unwrap();
+                                let mut use_next = false;
+                                for room_id in app.joined_rooms.iter() {
+                                    if use_next {
+                                        if app.selected_room.clone().unwrap()
+                                            == app.joined_rooms[find_bottom(
+                                                app.room_list_top,
+                                                app.room_list_height,
+                                                app.joined_rooms.len(),
+                                            )]
+                                        {
+                                            app.room_list_top += 1;
+                                        }
+                                        app.selected_room = Some(room_id.clone());
+                                        break;
+                                    } else if room_id != last {
+                                        if room_id.clone() == app.selected_room.clone().unwrap() {
+                                            use_next = true;
+                                        }
+                                    } else {
+                                        app.selected_room = Some(first.clone());
+                                        app.room_list_top = 0;
+                                    }
+                                }
+                            }
+                        }
+                        KeyCode::Char('l') => {
+                            tx2.send(SyncMessage::LeaveRoom(app.selected_room.clone().unwrap()))
+                                .unwrap();
+                            app.selected_room = None;
+                        }
+                        KeyCode::Char('j') => {
+                            app.focus = Focus::JoinRoomInput;
+                        }
+                        KeyCode::Enter => {
+                            app.current_room = Some(app.selected_room.clone().unwrap());
+                            app.selected_room = None;
+                            app.focus = Focus::Watching;
+                            app.room_list_top_backup = app.room_list_top;
+                        }
+                        KeyCode::Esc => {
+                            app.selected_room = None;
+                            app.focus = Focus::Watching;
+                            app.room_list_top = app.room_list_top_backup;
+                        }
+                        _ => {}
+                    },
                     Focus::Watching => match key.code {
                         KeyCode::Char('e') => {
                             app.focus = Focus::MessageInput;
-                            //app.messages.push(String::from("test"));
                         }
                         KeyCode::Char('q') => {
                             tx2.send(SyncMessage::Quit).unwrap();
-                            networking.await.unwrap();
+                            networking.abort();
                             return Ok(());
                         }
                         KeyCode::Char('r') => {
                             app.focus = Focus::RoomSelect;
                         }
-                        _ => {
-                            /*
-                            if let Ok(msg) = rx1.try_recv() {
-                                if let SyncMessage::SendMessage(room_id, user_id, message) = msg {
-                                    app.messages.push(format!("[{}] <{}> {}", room_id, user_id, message));
-                                }
-                            }
-                            */
-                        }
+                        _ => {}
                     },
                     Focus::MessageInput => match key.code {
                         KeyCode::Enter => {
                             let message: String = app.input.drain(..).collect();
-                            //app.messages.push(message.clone());
                             if message != String::new() {
                                 let sync_message = SyncMessage::SendMessage(
                                     app.current_room.clone().unwrap(),
                                     format!("{}", me),
                                     message,
+                                    false,
                                 );
                                 tx1_clone.send(sync_message.clone()).unwrap();
                                 tx2.send(sync_message.clone()).unwrap();
@@ -469,22 +444,12 @@ async fn run_app<B: Backend>(terminal: &mut Terminal<B>, mut app: App) -> io::Re
                         KeyCode::Esc => {
                             app.focus = Focus::Watching;
                         }
-                        _ => {
-                            /*
-                            if let Ok(msg) = rx1.try_recv() {
-                                if let SyncMessage::SendMessage(room_id, user_id, message) = msg {
-                                    app.messages.push(format!("[{}] <{}> {}", room_id, user_id, message));
-                                }
-                            }
-                            */
-                        }
+                        _ => {}
                     },
                     Focus::JoinRoomInput => match key.code {
                         KeyCode::Enter => {
                             let room: String = app.input.drain(..).collect();
-                            //app.messages.push(message.clone());
                             let sync_message = SyncMessage::JoinRoom(room);
-                            //tx1_clone.send(sync_message.clone()).unwrap();
                             tx2.send(sync_message.clone()).unwrap();
                             app.focus = Focus::Watching;
                         }
@@ -497,24 +462,20 @@ async fn run_app<B: Backend>(terminal: &mut Terminal<B>, mut app: App) -> io::Re
                         KeyCode::Esc => {
                             app.focus = Focus::Watching;
                         }
-                        _ => {
-                            /*
-                            if let Ok(msg) = rx1.try_recv() {
-                                if let SyncMessage::SendMessage(room_id, user_id, message) = msg {
-                                    app.messages.push(format!("[{}] <{}> {}", room_id, user_id, message));
-                                }
-                            }
-                            */
-                        }
+                        _ => {}
                     },
                     Focus::InitialSync => {}
                 }
             }
         } else {
             if let Ok(msg) = rx1.try_recv() {
-                if let SyncMessage::SendMessage(room_id, user_id, message) = msg {
+                if let SyncMessage::SendMessage(room_id, user_id, message, is_emote) = msg {
                     let mut msgs = app.messages[&room_id].clone();
-                    msgs.push(format!("<{}> {}", user_id, message));
+                    if is_emote {
+                        msgs.push(format!("* {user_id} {message}"));
+                    } else {
+                        msgs.push(format!("<{}> {}", user_id, message));
+                    }
                     if msgs.len() > 100 {
                         msgs.remove(0);
                     }
@@ -530,7 +491,6 @@ async fn run_app<B: Backend>(terminal: &mut Terminal<B>, mut app: App) -> io::Re
                     alias_to_room,
                 ) = msg
                 {
-                    //app.rooms = room_id_list;
                     app.joined_rooms = room_id_list.clone();
                     app.rooms = room_to_name;
                     app.room_id_to_canonical_alias = room_id_to_canonical_alias;
@@ -542,17 +502,6 @@ async fn run_app<B: Backend>(terminal: &mut Terminal<B>, mut app: App) -> io::Re
                             app.messages.insert(room_id.clone(), Vec::new());
                         }
                     }
-                    /*
-                    for (room_id, room_name) in room_id_list {
-                        if app.current_room.is_none() {
-                            app.current_room = Some(room_id.clone());
-                        }
-                        if !app.rooms.contains_key(&room_id.clone()) {
-                            app.rooms.aaaaaa(room_id.clone(), room_name.clone());
-                            app.messages.insert(room_id.clone(), Vec::new());
-                        }
-                    }
-                    */
                 }
             }
         }
@@ -572,7 +521,6 @@ fn ui<B: Backend>(f: &mut Frame<B>, app: &mut App) {
             .as_ref(),
         )
         .split(f.size());
-    //message_box_height.store(chunks[1].height);
     let middle_chunk = Layout::default()
         .direction(Direction::Horizontal)
         .constraints([Constraint::Percentage(20), Constraint::Percentage(80)].as_ref())
@@ -664,11 +612,9 @@ fn ui<B: Backend>(f: &mut Frame<B>, app: &mut App) {
         }
         _ => {}
     }
-    //println!("{:#?}", app.joined_rooms);
     if app.joined_rooms.len() > 0 {
         if app.room_list_prev_height != app.room_list_height {
-            //let location: bool;
-            let chosen: RoomId;
+            let chosen: Box<RoomId>;
             if app.selected_room.is_none() {
                 chosen = app.current_room.clone().unwrap();
             } else {
@@ -697,18 +643,7 @@ fn ui<B: Backend>(f: &mut Frame<B>, app: &mut App) {
                     app.joined_rooms.len(),
                 );
             }
-        } /*else if app.room_list_prev_height > app.room_list_height {
-              app.room_list_top = find_top(
-                  find_bottom(
-                      app.room_list_top - (app.room_list_prev_height - app.room_list_height),
-                      app.room_list_height,
-                      app.joined_rooms.len(),
-                  ),
-                  app.room_list_height,
-                  app.joined_rooms.len(),
-              );
-              //app.room_list_top -= app.room_list_height - app.room_list_prev_height;
-          }*/
+        }
     }
     let room_list: Vec<ListItem> = app
         .joined_rooms
@@ -726,19 +661,19 @@ fn ui<B: Backend>(f: &mut Frame<B>, app: &mut App) {
                 return None;
             }
             let content: Vec<Spans>;
-            if app.rooms.contains_key(&room_id) {
+            if app.rooms.contains_key(room_id) {
                 content = vec![Spans::from(Span::raw(format!("{}", app.rooms[room_id])))];
-            } else if app.room_id_to_canonical_alias.contains_key(&room_id) {
+            } else if app.room_id_to_canonical_alias.contains_key(room_id) {
                 content = vec![Spans::from(Span::raw(format!(
                     "{}",
                     app.room_id_to_canonical_alias[room_id]
                 )))];
-            } else if app.room_to_aliases.contains_key(&room_id) {
+            } else if app.room_to_aliases.contains_key(room_id) {
                 content = vec![Spans::from(Span::raw(format!(
                     "{}",
                     app.room_to_aliases[room_id][0]
                 )))];
-            } else if app.room_to_direct_name.contains_key(&room_id) {
+            } else if app.room_to_direct_name.contains_key(room_id) {
                 content = vec![Spans::from(Span::raw(format!(
                     "{}",
                     app.room_to_direct_name[room_id]
@@ -746,23 +681,10 @@ fn ui<B: Backend>(f: &mut Frame<B>, app: &mut App) {
             } else {
                 content = vec![Spans::from(Span::raw(format!("{}", room_id)))];
             }
-            //let content: Vec<Span>;
             if app.current_room.is_none() {
                 app.current_room = Some(room_id.clone());
             }
             let current_room = app.current_room.clone().unwrap();
-            //if let Some(room) = current_room {
-            /*
-            if current_room == room_id.clone() {
-                content = vec![Span::from(Span::styled(
-                    format!("{}", room_name),
-                    Style::default().add_modifier(Modifier::BOLD),
-                ))];
-            } else {
-                content = vec![Span::from(Span::raw(format!("{}", room_name)))];
-            }
-            */
-            //}
             let mut z = ListItem::new(content);
             let mut style = Style::default();
             if room_id.clone() == current_room {
@@ -815,27 +737,16 @@ fn ui<B: Backend>(f: &mut Frame<B>, app: &mut App) {
     let mut msg_list: Vec<ListItem> = Vec::new();
     if app.current_room.is_some() {
         let ms = app.messages[&app.current_room.clone().unwrap()].join("\n");
-        //let width: i32 = middle_chunk[1].width.try_into().unwrap(); //message_box_height.load().try_into().unwrap();
         let lines: Vec<String> = textwrap::wrap(ms.as_str(), (middle_chunk[1].width - 2) as usize)
             .iter()
             .map(|x| x.to_string())
             .collect();
-        //.split("\n")
-        //.map(|x| x.to_string())
-        //.collect();
-        /*)
-        let messages_len: i32 = app.messages[&app.current_room.clone().unwrap()]
-            .len()
-            .try_into()
-            .unwrap();
-        */
         let messages_len: i32 = lines.len().try_into().unwrap();
         let height: i32 = middle_chunk[1].height.try_into().unwrap(); //message_box_height.load().try_into().unwrap();
         let mut cut_off = messages_len - height + 2;
         if cut_off <= 0 {
             cut_off = 0;
         }
-        //msg_list = app.messages[app.current_room.as_ref().unwrap()][cut_off.try_into().unwrap()..]
         msg_list = lines[cut_off.try_into().unwrap()..]
             .iter()
             .enumerate()
@@ -850,5 +761,4 @@ fn ui<B: Backend>(f: &mut Frame<B>, app: &mut App) {
     f.render_widget(messages, middle_chunk[1]);
     f.render_widget(input, chunks[2]);
     f.render_widget(room_list, middle_chunk[0]);
-    //println!("{}", chunks[1].height);
 }
